#!/usr/bin/env python

name = 'moment'
version = '0.7'
website = 'https://github.com/lepture/liquidluck-theme-moment'
author = {
    'name': 'Hsiaoming Yang',
    'website': 'http://lepture.com',
}


show_author = False
tagcloud = False
navigation = [
    ('Home', '/'),
    ('About', '/about.html'),
]

lang = 'en'
twitter = 'lepture'
github = None
disqus = None
analytics = None
